var indexSectionsWithContent =
{
  0: "5abcdefghiklmnopqrstuvwx",
  1: "b",
  2: "b",
  3: "b",
  4: "abcdefghiklmnopqrstuvx",
  5: "b",
  6: "b",
  7: "ab"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "defines",
  7: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Macros",
  7: "Pages"
};

